<?php

include 'config.php';

$settings['version'] = '1.00';

session_start();

$pdo_dsn = 'mysql:host='.$settings['MYSQL_HOST'].';dbname='.$settings['MYSQL_DB'].';charset='.$settings['MYSQL_CHARSET'];
$pdo_options = [
    PDO::ATTR_ERRMODE            => PDO::ERRMODE_EXCEPTION,
    PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
    PDO::ATTR_EMULATE_PREPARES   => false,
];
try {
    $pdo = new PDO($pdo_dsn, $settings['MYSQL_USER'], $settings['MYSQL_PASS'], $pdo_options);
} catch (PDOException $e) {
    throw new PDOException($e->getMessage(), (int)$e->getCode());
}

$action = '';
if (isset($_POST['act'])) {
    $action = $_POST['act'];
}

switch ($action) {
    case 'delete-links':
        $deleteQuery_array = array();
        $deleteQuery = 'DELETE FROM `links` WHERE ';
        $deleteQueryExtra = '1=1';
        // Are created by
        if (isset($_POST['links_method'])) {
            $deleteQueryExtra.= ' AND';
            $deleteQueryExtra.= ' method=:method';
            $deleteQuery_array[':method'] = (int)$_POST['links_method'];
        }
        // Are older than
        if (isset($_POST['links_created'])) {
            $deleteQueryExtra.= ' AND';
            $deleteQueryExtra.= ' created<:created';
            switch ($_POST['links_created']) {
                case '1week':
                    $deleteQuery_array[':created'] = date('Y-m-d H:i:s', time()-86400*7);
                break;
                case '1month':
                    $deleteQuery_array[':created'] = date('Y-m-d H:i:s', time()-86400*31);
                break;
            }
        }
        // Have less than
        if (isset($_POST['links_hits'])) {
            $deleteQueryExtra.= ' AND';
            $deleteQueryExtra.= ' hits<:hits';
            $deleteQuery_array[':hits'] = (int)$_POST['links_hits'];
        }
        // Alias start with
        if ((isset($_POST['start_with'])) && ($_POST['start_with']!='')) {
            $deleteQueryExtra.= ' AND';
            $deleteQueryExtra.= ' alias LIKE :alias';
            $deleteQuery_array[':alias'] = $_POST['start_with'].'%';
        }
        // Prepare
        $deleteQuery.= $deleteQueryExtra;
        $pdo_statement = $pdo->prepare($deleteQuery);
        $pdo_statement->execute($deleteQuery_array);
        $itemsCount = $pdo_statement->rowcount();
        $pdo->exec('OPTIMIZE TABLE `links`;');
        $_SESSION['adlinkfly-cleaner-message-links'] = $itemsCount.' links removed!';
        header('Location: .');
        exit;
    break;
    case 'delete-stats':
        // get all campaign IDs
        $campaign_ids_array = array();
        $pdo_statement = $pdo->query("SELECT id FROM `campaigns`;");
        $campaign_ids = $pdo_statement->fetchAll(PDO::FETCH_ASSOC);
        foreach ($campaign_ids as $campaignItem) {
            $campaign_ids_array[] = $campaignItem['id'];
        }
        // delete all stats that are not linked to a campaign or a link
        $selectQuery_array = array();
        $selectQuery = 'DELETE s FROM `statistics` AS s LEFT JOIN `links` AS l ON s.link_id=l.id WHERE ';
        $selectQueryExtra = 'l.id IS NULL';
        if (count($campaign_ids_array)>0) {
            $selectQueryExtra.= ' AND s.campaign_id NOT IN ('.implode(',', $campaign_ids_array).')';
        }
        $selectQuery.= $selectQueryExtra;
        $itemsCount = $pdo->exec($selectQuery);
        $pdo->exec('OPTIMIZE TABLE `statistics`;');
        $_SESSION['adlinkfly-cleaner-message-stats'] = $itemsCount.' items removed!';
        header('Location: .');
        exit;
    break;
}

?>
<html>
<head>
<style>
* {
    font-family: verdana;
    font-size: 12px;
}

.status_error {
    color: #AA0000;
    margin-bottom: 7px;
}
.status_success {
    color: #009900;
    margin-bottom: 7px;
}

.button_delete {
    background-color: #FFAAAA;
    border:1px solid #FF0000;
    border-radius: 5px;
    padding: 6px;
    cursor: pointer;
}

.block {
    background-color: #FAFAFA;
    padding: 5px;
    border:1px solid #DDDDDD;
    border-radius: 10px;
}
</style>
<title>AdLinkFly Cleaner <?php echo $settings['version']; ?></title>
</head>
<body>

<h1>AdLinkFly Cleaner <?php echo $settings['version']; ?></h1>
<div class="block">
<h2>Links</h2>
<?php
if (isset($_SESSION['adlinkfly-cleaner-message-links'])) {
    echo '<div class="status_success">'.$_SESSION['adlinkfly-cleaner-message-links'].'</div>';
    unset($_SESSION['adlinkfly-cleaner-message-links']);
}
?>
<form method="post" action=".">
<input type="hidden" name="act" value="delete-links" />
Delete Links That:<br />
<br />
Are created by:<br />
<select name="links_method">
    <option value="1">web</option>
    <option value="2">quick</option>
    <option value="3">mass</option>
    <option value="4">full</option>
    <option value="5" selected="selected">api</option>
    <option value="6">bookmarklet</option>
</select>
<br />
<br />
And<br />
<br />
Are older than:<br />
<select name="links_created">
    <option value="1week" selected="selected">1 week</option>
    <option value="1month">1 month</option>
</select>
<br />
<br />
And<br />
<br />
Have less than:<br />
<select name="links_hits">
    <option value="3">3 hits</option>
    <option value="5">5 hits</option>
    <option value="10">10 hits</option>
    <option value="20">20 hits</option>
    <option value="50">50 hits</option>
    <option value="100">100 hits</option>
    <option value="1000">1000 hits</option>
    <option value="10000">10000 hits</option>
    <option value="100000">100000 hits</option>
    <option value="1000000" selected="selected">1000000 hits</option>
</select>
<br />
<br />
And<br />
<br />
Alias start with:<br />
<input type="text" name="start_with" value="FBu" />
<br />
<br />
<input type="submit" class="button_delete" value="Delete Links" />
</form>
</div>
<br />
<br />

<div class="block">
<h2>Statistics</h2>
<?php
if (isset($_SESSION['adlinkfly-cleaner-message-stats'])) {
    echo '<div class="status_success">'.$_SESSION['adlinkfly-cleaner-message-stats'].'</div>';
    unset($_SESSION['adlinkfly-cleaner-message-stats']);
}
?>
<form method="post" action=".">
<input type="hidden" name="act" value="delete-stats" />
Delete Statistics That:<br />
<br />
<select name="belong_to_link">
    <option value="no" selected="selected">Don't belong to any link</option>
</select>
<br />
<br />
And<br />
<br />
<select name="belong_to_campaign">
    <option value="no" selected="selected">Don't belong to any campaign</option>
</select>
<br />
<br />
<input type="submit" class="button_delete" value="Delete Statistics" />
</form>
</div>
</body>
</html>
